@@ -26,6 +26,7 @@ import BaseHTTPServer
 import docutils.core
 import docutils.writers.html4css1
 import cgi
+import urllib
 
 try:
     import pygments
@@ -35,7 +36,7 @@ except ImportError:
     pygments = None
 
 
-__version__ = "1.2"
+__version__ = "1.2.1"
 
 
 class MyRequestHandler(BaseHTTPServer.BaseHTTPRequestHandler):
@@ -52,6 +53,7 @@ class MyRequestHandler(BaseHTTPServer.BaseHTTPRequestHandler):
         content = self.do_GET_or_HEAD()
 
     def do_GET_or_HEAD(self):
+        self.path = urllib.unquote(self.path)
         root = self.server.renderer.root
         command = self.server.renderer.command
         if self.path == '/':
@@ -105,7 +107,7 @@ class MyRequestHandler(BaseHTTPServer.BaseHTTPRequestHandler):
             finally:
                 f.close()
         except IOError, e:
-            self.log_error("%s" % e)
+            self.log_error("%s", e)
             self.send_error(404, "File not found")
 
     def handle_command(self, command):
@@ -289,6 +291,8 @@ class RestViewer(object):
 class SyntaxHighlightingHTMLTranslator(docutils.writers.html4css1.HTMLTranslator):
 
     in_doctest = False
+    in_text = False
+    in_reference = False
 
     def visit_doctest_block(self, node):
         docutils.writers.html4css1.HTMLTranslator.visit_doctest_block(self, node)
@@ -310,18 +314,42 @@ class SyntaxHighlightingHTMLTranslator(docutils.writers.html4css1.HTMLTranslator
             self.body.append(pygments.highlight(text, lexer, formatter))
         else:
             text = node.astext()
+            self.in_text = True
             encoded = self.encode(text)
+            self.in_text = False
             if self.in_mailto and self.settings.cloak_email_addresses:
                 encoded = self.cloak_email(encoded)
             self.body.append(encoded)
 
+    def visit_literal(self, node):
+        self.in_text = True
+        docutils.writers.html4css1.HTMLTranslator.visit_literal(self, node)
+        self.in_text = False
+
+    def visit_reference(self, node):
+        self.in_reference = True
+        docutils.writers.html4css1.HTMLTranslator.visit_reference(self, node)
+
+    def depart_reference(self, node):
+        docutils.writers.html4css1.HTMLTranslator.depart_reference(self, node)
+        self.in_reference = False
+
     def encode(self, text):
         encoded = docutils.writers.html4css1.HTMLTranslator.encode(self, text)
-        encoded = self.link_local_files(encoded)
+        if self.in_text and not self.in_reference:
+            encoded = self.link_local_files(encoded)
         return encoded
 
-    def link_local_files(self, text):
-        """Replace filenames with hyperlinks."""
+    @staticmethod
+    def link_local_files(text):
+        """Replace filenames with hyperlinks.
+
+            >>> link_local_files = SyntaxHighlightingHTMLTranslator.link_local_files
+            >>> link_local_files('e.g. see README.txt for more info')
+            'e.g. see <a href="README.txt">README.txt</a> for more info'
+
+        """
+        # jwz was right...
         text = re.sub("([-_a-zA-Z0-9]+[.]txt)", r'<a href="\1">\1</a>', text)
         return text
 
